unit CustomPreview;

interface

Uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  RpDefine, RpBase, RpSystem, StdCtrls, CustomFormPreview, CustomFormStatus,
  CustomFormSetup;

procedure ExecuteStatusForm(AOwner:TComponent; ReportSystem: TRvSystem; OverrideMode: TOverrideMode; var OverrideForm: TForm);
procedure ExecuteSetupForm(AOwner:TComponent; ReportSystem: TRvSystem; OverrideMode: TOverrideMode; var OverrideForm: TForm);
Procedure ExecutePreviewForm(AOwner:TComponent; ReportSystem: TRvSystem; OverrideMode: TOverrideMode; var OverrideForm: TForm);

implementation

//==============================================================================
// Esta rotina sobrepor o formulrio de Status da impressao do Rave.
// Exemplo de uso: No evento OnOverrideStatus escreva:
//
// Begin
//   ExecuteStatusForm(Self,ReportSystem,OverrideMode,OverrideForm);
// End;
//==============================================================================
procedure ExecuteStatusForm(AOwner:TComponent; ReportSystem: TRvSystem; OverrideMode: TOverrideMode; var OverrideForm: TForm);
Begin
  if not (soShowStatus in ReportSystem.SystemOptions) then Exit;

  case OverrideMode of
    omCreate: begin
      OverrideForm := TCustomStatusForm.Create(AOWner);
      OverrideForm.Caption := ReportSystem.TitleStatus;
      (OverrideForm as TCustomStatusForm).ReportSystem := ReportSystem;
    end;
    omShow: begin
      with OverrideForm as TCustomStatusForm,ReportSystem do begin
        BaseReport.StatusLabel := StatusLabel;
        CancelButton.Caption := Trans('Cancelar');
        Show;
      end;
    end;
    omWait: begin
      with OverrideForm as TCustomStatusForm,ReportSystem do begin
        if soWaitForOK in SystemOptions then begin
          CancelButton.Caption := Trans('Ok');
          CancelButton.ModalResult := mrOk;
          FormClosed := false;
          repeat
            Application.ProcessMessages;
          until FormClosed;
        end;
      end;
    end;
    omFree: begin
      FreeAndNil(OverrideForm);
    end;
  end;
End;

//==============================================================================
// Esta rotina sobrepor o formulrio de Setup  da impressao do Rave.
// Exemplo de uso: No evento OnOverrideSetup  escreva:
//
// Begin
//   ExecuteSetupForm(Self,ReportSystem,OverrideMode,OverrideForm);
// End;
//==============================================================================
procedure ExecuteSetupForm(AOwner:TComponent; ReportSystem: TRvSystem; OverrideMode: TOverrideMode; var OverrideForm: TForm);
Begin
  case OverrideMode of
    omCreate: begin
      OverrideForm := TCustomSetupForm.Create(AOwner);
      OverrideForm.Caption := ReportSystem.TitleSetup;
      (OverrideForm as TCustomSetupForm).ReportSystem := ReportSystem;
    end;
    omShow: begin
      with OverrideForm as TCustomSetupForm,ReportSystem do begin
        PreviewSetup := false;
        Aborted := ShowModal = mrCancel;
      end;
    end;
    omWait: begin
    end;
    omFree: begin
      FreeAndNil(OverrideForm);
    end;
  end;
End;

//==============================================================================
// Esta rotina sobrepor o formulrio de Preview da impressao do Rave.
// Exemplo de uso: No evento OnOverridePreview escreva:
//
// Begin
//   ExecutePreviewForm(Self,ReportSystem,OverrideMode,OverrideForm);
// End;
//==============================================================================
Procedure ExecutePreviewForm(AOwner:TComponent; ReportSystem: TRvSystem; OverrideMode: TOverrideMode; var OverrideForm: TForm);
begin
  case OverrideMode of
    omCreate: begin
      OverrideForm := TCustomPreviewForm.Create(AOwner);
      OverrideForm.Caption := ReportSystem.TitlePreview;
      OverrideForm.Width := ReportSystem.SystemPreview.FormWidth;
      OverrideForm.Height := ReportSystem.SystemPreview.FormHeight;
      OverrideForm.WindowState := ReportSystem.SystemPreview.FormState;
      (OverrideForm as TCustomPreviewForm).ReportSystem := ReportSystem;


      { esta linha abaixo no  compativel com o Rave 5.0.04 }
      (OverrideForm as TCustomPreviewForm).OnAfterPreviewPrint := ReportSystem.OnAfterPreviewPrint;
    end;
    omShow: begin
      (OverrideForm as TCustomPreviewForm).RvRenderPrinter.MacroData.Assign(ReportSystem.StorageMacroData);
      (OverrideForm as TCustomPreviewForm).RvRenderPreview.MacroData.Assign(ReportSystem.StorageMacroData);


      { esta 2 linhas abaixo no so compativeis com o Rave 5.0.04 }
      (OverrideForm as TCustomPreviewForm).RvRenderPrinter.OnDecodeImage := ReportSystem.OnDecodeImage;
      (OverrideForm as TCustomPreviewForm).RvRenderPreview.OnDecodeImage := ReportSystem.OnDecodeImage;

      ReportSystem.SystemPreview.InitPreview((OverrideForm as TCustomPreviewForm).RvRenderPreview);
      if Assigned(ReportSystem.OnPreviewSetup) then begin
        ReportSystem.OnPreviewSetup((OverrideForm as TCustomPreviewForm).RvRenderPreview);
      end;

      (OverrideForm as TCustomPreviewForm).InputFileName := ReportSystem.SystemFiler.Filename;
      (OverrideForm as TCustomPreviewForm).InputStream := ReportSystem.SystemFiler.Stream;
      (OverrideForm as TCustomPreviewForm).InitFromRPSystem;

      if soPreviewModal in ReportSystem.SystemOptions then begin
        OverrideForm.ShowModal;
      end else begin
        OverrideForm.Show;
      end;
    end;
    omWait: begin
      if not (soPreviewModal in ReportSystem.SystemOptions) then begin
        repeat
          Sleep(250);
          Application.ProcessMessages;
        until not OverrideForm.Visible;
      end;
    end;
    omFree: begin
      if (ReportSystem.SystemFiler.StreamMode in [smTempFile,smFile]) then begin
        (OverrideForm as TCustomPreviewForm).RvRenderPreview.NDRStream.Free;
        (OverrideForm as TCustomPreviewForm).RvRenderPreview.NDRStream := nil;
      end;
      FreeAndNil(OverrideForm);
    end;
  end;
End;

end.
